diff --git a/sc/inc/scfuncs.hrc b/sc/inc/scfuncs.hrc
index 9f8cce9b0090..7a129a046a11 100644
--- a/sc/inc/scfuncs.hrc
+++ b/sc/inc/scfuncs.hrc
@@ -4248,7 +4248,7 @@ const TranslateId SC_OPCODE_RANDARRAY_ARY[] =
NC_("SC_OPCODE_RANDARRAY", "Max"),
NC_("SC_OPCODE_RANDARRAY", "The upper limit of the generated numbers."),
NC_("SC_OPCODE_RANDARRAY", "Integers"),
- NC_("SC_OPCODE_RANDARRAY", "Return whole numbers (TRUE) or decimal values (FALSE).")
+ NC_("SC_OPCODE_RANDARRAY", "Return integer (TRUE) or decimal (FALSE) values.")
};
// -=*# Resource for function UNIQUE #*=-
diff --git a/sc/qa/uitest/validity/validity.py b/sc/qa/uitest/validity/validity.py
index 3112b7afb91e..158b3905eaba 100644
--- a/sc/qa/uitest/validity/validity.py
+++ b/sc/qa/uitest/validity/validity.py
@@ -29,7 +29,7 @@ class validity(UITestCase):
xmin = xDialog.getChild("min")
xmax = xDialog.getChild("max")
- select_by_text(xallow, "Whole Numbers")
+ select_by_text(xallow, "Integer")
xallowempty.executeAction("CLICK", tuple())
select_by_text(xdata, "valid range")
xmin.executeAction("TYPE", mkPropertyValues({"TEXT":"1"}))
@@ -42,7 +42,7 @@ class validity(UITestCase):
xmin = xDialog.getChild("min")
xmax = xDialog.getChild("max")
- self.assertEqual(get_state_as_dict(xallow)["SelectEntryText"], "Whole Numbers")
+ self.assertEqual(get_state_as_dict(xallow)["SelectEntryText"], "Integer")
self.assertEqual(get_state_as_dict(xallowempty)["Selected"], "false")
self.assertEqual(get_state_as_dict(xdata)["SelectEntryText"], "valid range")
self.assertEqual(get_state_as_dict(xmin)["Text"], "1")
diff --git a/sc/uiconfig/scalc/ui/validationcriteriapage.ui b/sc/uiconfig/scalc/ui/validationcriteriapage.ui
index 5703ae0e2e4a..392490b37cb5 100644
--- a/sc/uiconfig/scalc/ui/validationcriteriapage.ui
+++ b/sc/uiconfig/scalc/ui/validationcriteriapage.ui
@@ -45,7 +45,7 @@
False
- All values
- - Whole Numbers
+ - Integer
- Decimal
- Date
- Time
diff --git a/sc/qa/uitest/validity/tdf138134.py b/sc/qa/uitest/validity/tdf138134.py
index b13da491eb40..5d5023a50519 100644
--- a/sc/qa/uitest/validity/tdf138134.py
+++ b/sc/qa/uitest/validity/tdf138134.py
@@ -25,7 +25,7 @@ class DetectiveCircle(UITestCase):
#Select the cells to be validated
gridwin.executeAction("SELECT", mkPropertyValues({"CELL": "A3"}))
#Apply Data > Validity ... > Whole Numbers
with self.ui_test.execute_dialog_through_command(".uno:Validation") as xDialog:
xTabs = xDialog.getChild("tabcontrol")
select_pos(xTabs, "0")
@@ -34,7 +34,7 @@ class DetectiveCircle(UITestCase):
xdata = xDialog.getChild("data")
xmin = xDialog.getChild("min")
- select_by_text(xallow, "Whole Numbers")
+ select_by_text(xallow, "Integer")
xallowempty.executeAction("CLICK", tuple())
select_by_text(xdata, "equal")
xmin.executeAction("TYPE", mkPropertyValues({"TEXT":"5"}))
@@ -25,7 +25,7 @@ class DetectiveCircle(UITestCase):
#Select the cells to be validated
gridwin.executeAction("SELECT", mkPropertyValues({"CELL": "A3"}))
- #Apply Data > Validity ... > Whole Numbers
+ #Apply Data > Validity ... > Integer
with self.ui_test.execute_dialog_through_command(".uno:Validation") as xDialog:
xTabs = xDialog.getChild("tabcontrol")
diff --git a/sc/qa/uitest/validity/tdf150098.py b/sc/qa/uitest/validity/tdf150098.py
index 5d29a4afaadf..91384fc61ece 100644
--- a/sc/qa/uitest/validity/tdf150098.py
+++ b/sc/qa/uitest/validity/tdf150098.py
@@ -26,7 +26,7 @@ class EvaluateFormulaInputs(UITestCase):
#Select the cells to be validated
gridwin.executeAction("SELECT", mkPropertyValues({"CELL": "A4"}))
#Apply Data > Validity ... > Whole Numbers
with self.ui_test.execute_dialog_through_command(".uno:Validation") as xDialog:
xTabs = xDialog.getChild("tabcontrol")
select_pos(xTabs, "0")
@@ -35,7 +35,7 @@ class EvaluateFormulaInputs(UITestCase):
xdata = xDialog.getChild("data")
xmin = xDialog.getChild("min")
- select_by_text(xallow, "Whole Numbers")
+ select_by_text(xallow, "Integer")
xallowempty.executeAction("CLICK", tuple())
select_by_text(xdata, "equal")
xmin.executeAction("TYPE", mkPropertyValues({"TEXT":"A3"}))
@@ -26,7 +26,7 @@ class EvaluateFormulaInputs(UITestCase):
#Select the cells to be validated
gridwin.executeAction("SELECT", mkPropertyValues({"CELL": "A4"}))
- #Apply Data > Validity ... > Whole Numbers
+ #Apply Data > Validity ... > Integer
with self.ui_test.execute_dialog_through_command(".uno:Validation") as xDialog:
xTabs = xDialog.getChild("tabcontrol")